Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(798)

Unified Diff: chrome/browser/chromeos/dom_ui/language_options_handler.h

Issue 3072028: Build the language list just like we do in the C++ version. (Closed)
Patch Set: address comments Created 10 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/chromeos/dom_ui/language_options_handler.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chromeos/dom_ui/language_options_handler.h
diff --git a/chrome/browser/chromeos/dom_ui/language_options_handler.h b/chrome/browser/chromeos/dom_ui/language_options_handler.h
index d8a957a57c5d5bac08bfcc043633c9e9e526d121..a5d04d4552a2780adcee11d245aaeb9816ed4b56 100644
--- a/chrome/browser/chromeos/dom_ui/language_options_handler.h
+++ b/chrome/browser/chromeos/dom_ui/language_options_handler.h
@@ -6,6 +6,7 @@
#define CHROME_BROWSER_CHROMEOS_DOM_UI_LANGUAGE_OPTIONS_HANDLER_H_
#pragma once
+#include "chrome/browser/chromeos/input_method/input_method_util.h"
#include "chrome/browser/dom_ui/options_ui.h"
class DictionaryValue;
@@ -26,14 +27,16 @@ class LanguageOptionsHandler : public OptionsPageUIHandler {
virtual void RegisterMessages();
private:
// Gets the list of input methods. The return value will look like:
// [{'id': 'pinyin', 'displayName': 'Pinyin', 'languageCode': 'zh-CW'}, ...]
- ListValue* GetInputMethodList();
+ ListValue* GetInputMethodList(const InputMethodDescriptors& descriptors);
- // Gets the list of languages. The return value will look like:
+ // Gets the list of languages from the given input descriptors.
+ // The return value will look like:
// [{'code': 'fi', 'displayName': 'Finnish', 'nativeDisplayName': 'suomi'},
// ...]
- ListValue* GetLanguageList();
+ ListValue* GetLanguageList(const InputMethodDescriptors& descriptors);
// Called when the UI language is changed.
// |value| will be the language code as string (ex. "fr").
« no previous file with comments | « no previous file | chrome/browser/chromeos/dom_ui/language_options_handler.cc » ('j') | no next file with comments »
@@ -26,14 +27,16 @@ class LanguageOptionsHandler : public OptionsPageUIHandler {
virtual void RegisterMessages();
private:
- // Gets the list of input methods. The return value will look like:
+ // Gets the list of input methods from the given input descriptors.
+ // The return value will look like:
// [{'id': 'pinyin', 'displayName': 'Pinyin', 'languageCode': 'zh-CW'}, ...]

Powered by Google App Engine
This is Rietveld 408576698